# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version         | Supported          |
|-----------------|--------------------|
| `main@HEAD`     | :white_check_mark: |
| Everything else | :x:                |

## Reporting a Vulnerability

Vulnerabilities can currently be reported as security advisories at 
[this link](https://github.com/smlxl/storage-layout-extractor/security/advisories/new).
